@@ -1,5 +1,6 @@
 import re
 
+
 class BinaryNotFoundError(Exception):
     def __init__(self, msg):
         Exception.__init__(self, msg)
@@ -44,7 +45,7 @@ class UnknownModelError(Exception):
 
 class ResultRetrievalError(Exception):
     def __init__(self):
-        msg = 'Failed to retrieve simulation results, could not read output files.'
+        msg = "Failed to retrieve simulation results, could not read output files."
         Exception.__init__(self, msg)
 
 
@@ -69,26 +70,25 @@ def parse_error_string_compiler(out_string: str, error_string: str):
         _error = [i for i in out_string.split("\n") if i and i[0] == "["]
         raise OMParsingError(", ".join(_error))
     elif "Execution failed!" in error_string:
-        raise OMExecutionError(
-            f"Failed to execute compiled code:\n{out_string}"
-        )
+        raise OMExecutionError(f"Failed to execute compiled code:\n{out_string}")
     elif "failed" in out_string:
         raise OMBuildError(
-            ", ".join(
-                [i for i in out_string.split("\n") if "failed" in i.lower()]
-            )
+            ", ".join([i for i in out_string.split("\n") if "failed" in i.lower()])
         )
 
 
-def parse_error_string_simulate(out_string: str, terminate_on_assert: str = 'error'):
+def parse_error_string_simulate(out_string: str, terminate_on_assert: str = "error"):
+    print(out_string)
     if "division by zero" in out_string:
         _line = [i for i in out_string.split("\n") if "division by zero" in i]
         raise ZeroDivisionError(_line[0].split("|")[-1].strip())
+    elif "simulation terminated by an assertion" in out_string:
+        raise OMAssertionError(f"Simulation run failed:\n{out_string}")
 
-    _find_assert = re.compile(r'assert\s*\|\s*(\w+)\s*\|', re.IGNORECASE)
+    _find_assert = re.compile(r"assert\s*\|\s*(\w+)\s*\|", re.IGNORECASE)
     _asserts = _find_assert.findall(out_string)
 
-    _assertion_ranking = ('debug', 'info', 'warning', 'error', 'never')
+    _assertion_ranking = ("debug", "info", "warning", "error", "never")
 
     if not _asserts:
         return
